@@ -1167,6 +1167,16 @@ exit(1)
 """)
         self.assertRaises(ErrorReturnCode_1, python, py.name)
         
+    # designed to check if the ErrorReturnCode constructor does not raise
+    # an UnicodeDecodeError
+    def test_non_ascii_error(self):
+        from sh import ls, ErrorReturnCode
+        
+        test = "/á"
+        if not IS_PY3: test = test.decode("utf8")
+        
+        self.assertRaises(ErrorReturnCode, ls, test)
+        
 
 if __name__ == "__main__":
     if len(sys.argv) > 1:
